@@ -85,13 +85,12 @@ class StiltStation():
 
     def __str__(self):
         # by default called when a an 'object' is printed
-
+        
         out = {'id:': self.id,
                'name:': self.name,
                'lat:': self.lat,
                'lon:': self.lon,
-               'alt [m]:': self.alt,
-               'country': self.geoinfo['name']
+               'alt [m]:': self.alt
                }
         return json.dumps(out)
 
@@ -122,7 +121,7 @@ class StiltStation():
         columns : TYPE, optional
             Valid entries are "default", "co2", "co", "rn", "wind", "latlon", "all"
             default (or empty) will return
-            ["isodate","co2.stilt","co2.fuel","co2.bio", "co2.background"]
+            ["isodate","co2.stilt","co2.bio","co2.fuel","co2.cement","co2.background"]
             A full description of the 'columns' can be found at
             https://icos-carbon-portal.github.io/pylib/modules/#stilt
 
@@ -396,20 +395,25 @@ class StiltStation():
 
         #Check columns-input:
         if cols=='default':
-            columns = ('["isodate","co2.stilt","co2.fuel","co2.bio", "co2.background"]')
+            columns = ('["isodate","co2.stilt","co2.bio","co2.fuel","co2.cement",'+ 
+                       '"co2.background"]')
 
         elif cols=='co2':
-            columns = ('["isodate","co2.stilt","co2.fuel","co2.bio","co2.fuel.coal",'+
-                       '"co2.bio.gee", "co2.bio.resp",' +
-                    '"co2.fuel.oil","co2.fuel.gas","co2.fuel.bio","co2.energy",'+
-                    '"co2.transport", "co2.industry","co2.others", "co2.cement",'+
-                    '"co2.background"]')
+            columns = ('["isodate","co2.stilt","co2.bio","co2.fuel","co2.cement",'+
+                       '"co2.bio.gee","co2.bio.resp",' +
+                       '"co2.fuel.coal","co2.fuel.oil","co2.fuel.gas",'+
+                       '"co2.fuel.bio","co2.fuel.waste",'+
+                       '"co2.energy","co2.transport","co2.industry",'+
+                       '"co2.residential","co2.other_categories",'+
+                       '"co2.background"]')
 
         elif cols=='co':
-            columns = ('["isodate", "co.stilt","co.fuel","co.bio","co.fuel.coal",'+
-                    '"co.fuel.oil", "co.fuel.gas","co.fuel.bio","co.energy",'+
-                    '"co.transport","co.industry", "co.others", "co.cement",'+
-                    '"co.background"]')
+            columns = ('["isodate", "co.stilt","co.fuel","co.cement",'+
+                       '"co.fuel.coal","co.fuel.oil", "co.fuel.gas",'+
+                       '"co.fuel.bio","co.fuel.waste",'+
+                       '"co.energy","co.transport","co.industry",'+
+                       '"co.residential","co.other_categories",'+
+                       '"co.background"]')
 
         elif cols=='rn':
             columns = ('["isodate", "rn", "rn.era", "rn.noah"]')
@@ -421,15 +425,22 @@ class StiltStation():
             columns = ('["isodate", "latstart", "lonstart"]')
 
         elif cols=='all':
-            columns = ('["isodate","co2.stilt","co2.fuel","co2.bio","co2.fuel.coal",'+
-                    '"co2.fuel.oil","co2.fuel.gas","co2.fuel.bio","co2.energy",'+
-                    '"co2.transport", "co2.industry","co2.others", "co2.cement",'+
-                    '"co2.background", "co.stilt","co.fuel","co.bio","co2.bio.gee",' +
-                    '"co2.bio.resp", "co.fuel.coal",'+
-                    '"co.fuel.oil","co.fuel.gas","co.fuel.bio","co.energy",'+
-                    '"co.transport","co.industry","co.others", "co.cement",'+
-                    '"co.background","rn", "rn.era","rn.noah","wind.dir",'+
-                    '"wind.u","wind.v","latstart","lonstart"]')
+            columns = ('["isodate","co2.stilt","co2.bio","co2.fuel","co2.cement",'+
+                       '"co2.bio.gee", "co2.bio.resp",' +
+                       '"co2.fuel.coal","co2.fuel.oil","co2.fuel.gas",'+
+                       '"co2.fuel.bio","co2.fuel.waste",'+
+                       '"co2.energy","co2.transport", "co2.industry",'+
+                       '"co2.residential","co2.other_categories",'+
+                       '"co2.background",'+
+                       '"co.stilt","co.fuel","co.cement",'+
+                       '"co.fuel.coal","co.fuel.oil","co.fuel.gas",'+
+                       '"co.fuel.bio","co.fuel.waste",'+
+                       '"co.energy","co.transport","co.industry",'+
+                       '"co.residential","co.other_categories",'+
+                       '"co.background",'+
+                       '"rn", "rn.era","rn.noah",'+
+                       '"wind.dir","wind.u","wind.v",'+
+                       '"latstart","lonstart"]')
 
         #Return variable:
         return columns
